@@ -113,7 +113,7 @@ enum {
 #include "lib/net-features.h"
 
 char *Release   = RELEASE,
-     *Version   = "netstat 1.20 (1997-05-01)",
+     *Version   = "netstat 1.21 (1997-05-11)",
      *Signature = "Fred Baumgarten <dc6iq@insu1.etec.uni-karlsruhe.de> and Alan Cox.";
 
 
@@ -1280,10 +1280,14 @@ ife_print(struct interface *ptr)
 static void if_getstats(char *ifname, struct interface *ife)
 {
   FILE *f=fopen("/proc/net/dev","r");
+  int have_byte_counters=0;
   char buf[256];
   char *bp;
   if(f==NULL)
   	return;
+  fgets(buf, 255, f);  /* throw away first line of header */
+  fgets(buf, 255, f);
+  if (strstr(buf, "bytes")) have_byte_counters=1;
   while(fgets(buf,255,f))
   {
   	bp=buf;
@@ -1293,23 +1297,43 @@ static void if_getstats(char *ifname, struct interface *ife)
   	{
  		bp=strchr(bp,':');
  		bp++;
- 		sscanf(bp,"%ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld",
-		        &ife->stats.rx_bytes,
- 			&ife->stats.rx_packets,
- 			&ife->stats.rx_errors,
- 			&ife->stats.rx_dropped,
- 			&ife->stats.rx_fifo_errors,
- 			&ife->stats.rx_frame_errors,
- 			
-		        &ife->stats.tx_bytes,
- 			&ife->stats.tx_packets,
- 			&ife->stats.tx_errors,
- 			&ife->stats.tx_dropped,
- 			&ife->stats.tx_fifo_errors,
- 			&ife->stats.collisions,
- 			
- 			&ife->stats.tx_carrier_errors
- 		);
+		if (have_byte_counters) {
+		  sscanf(bp,"%ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld",
+			 &ife->stats.rx_bytes,
+			 &ife->stats.rx_packets,
+			 &ife->stats.rx_errors,
+			 &ife->stats.rx_dropped,
+			 &ife->stats.rx_fifo_errors,
+			 &ife->stats.rx_frame_errors,
+			 
+			 &ife->stats.tx_bytes,
+			 &ife->stats.tx_packets,
+			 &ife->stats.tx_errors,
+			 &ife->stats.tx_dropped,
+			 &ife->stats.tx_fifo_errors,
+			 &ife->stats.collisions,
+			 
+			 &ife->stats.tx_carrier_errors
+			 );
+		} else {
+		  sscanf(bp,"%ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld",
+			 &ife->stats.rx_packets,
+			 &ife->stats.rx_errors,
+			 &ife->stats.rx_dropped,
+			 &ife->stats.rx_fifo_errors,
+			 &ife->stats.rx_frame_errors,
+			 
+			 &ife->stats.tx_packets,
+			 &ife->stats.tx_errors,
+			 &ife->stats.tx_dropped,
+			 &ife->stats.tx_fifo_errors,
+			 &ife->stats.collisions,
+			 
+			 &ife->stats.tx_carrier_errors
+			 );
+		  ife->stats.rx_bytes = 0;
+		  ife->stats.tx_bytes = 0;
+		}
  		fclose(f);
  		return;
   	}
